@@ -5,47 +5,48 @@ use utf8;
 
 BEGIN {
 	$Web::ID::AUTHORITY = 'cpan:TOBYINK';
-	$Web::ID::VERSION   = '1.924_03';
+	$Web::ID::VERSION   = '1.920';
 }
 
-use Web::ID::Types -types;
+use Any::Moose 'X::Types::Moose' => [':all'];
+use Web::ID::Types ':all';
 use Web::ID::Certificate;
 use Web::ID::Util qw(:default uniq);
 
-use Moose;
-use namespace::sweep;
+use Any::Moose;
+use namespace::clean -except => 'meta';
 
 has certificate => (
 	is          => read_only,
 	isa         => Certificate,
 	required    => true,
 	coerce      => true,
-);
+	);
 
 has uri => (
 	is          => read_only,
 	isa         => Uri,
 	lazy_build  => true,
 	coerce      => true,
-);
+	);
 
 has profile => (
 	is          => read_only,
 	isa         => Model,
 	lazy_build  => true,
-);
+	);
 
 has valid => (
 	is          => read_only,
 	isa         => Bool,
 	lazy_build  => true,
-);
+	);
 
 has first_valid_san => (
 	is          => read_only,
 	isa         => San | Undef,
 	lazy_build  => true,
-);
+	);
 
 sub _build_valid
 {
@@ -87,14 +88,14 @@ sub _build_first_valid_san
 sub node
 {
 	my ($self) = @_;
-	"RDF::Trine::Node::Resource"->new($self->uri.'');
+	RDF::Trine::Node::Resource->new($self->uri.'');
 }
 
 sub get
 {
 	my $self = shift;
 	my @pred = map {
-		if (blessed $_ and $_->isa("RDF::Trine::Node"))   {   $_ }
+		if (blessed $_ and $_->isa('RDF::Trine::Node'))   {   $_ }
 		else                                              { u $_ }
 	} @_;
 	
@@ -142,7 +143,7 @@ installed into web browsers.
 
 =item C<< new >>
 
-Standard Moose-style constructor. 
+Standard Moose-style constructor. (This class uses L<Any::Moose>.)
 
 =back
 
@@ -207,9 +208,60 @@ can do stuff like:
 
 =back
 
-=head1 BUGS
+=head1 BUGS AND LIMITATIONS
 
-Please report any bugs to
+=head2 Any::Moose
+
+This module uses L<Any::Moose> which means that if it detects that
+you're using the rather heavyweight L<Moose> toolkit, then this module
+will use it too. But if you're not using it, then this module will
+use the lighter-weight L<Mouse> toolkit.
+
+Similarly, this module will use either L<MouseX::Types> or
+L<MooseX::Types>.
+
+As the decision to use Moose or Mouse is made at runtime, this makes
+expressing Web::ID's dependencies rather challenging. Web::ID requires
+B<either>:
+
+=over
+
+=item * Any::Moose,
+
+=item * Mouse, and
+
+=item * MouseX::Types
+
+=back
+
+B<or>:
+
+=over
+
+=item * Any::Moose,
+
+=item * Moose, and
+
+=item * MooseX::Types
+
+=back
+
+The installation script for Web-ID checks the first set of
+dependencies, but if you only ever plan on using Moose, and never
+Mouse, then you don't need them - you need the second set.
+
+Yes, it's possible to have the installation script figure out
+a list of dependencies dynamically when you install Web-ID, but
+that's not especially helpful, as Any::Moose makes its decision
+about what module to use at run time, not at install time.
+
+The long and the short of it is: if you use Web::ID as part
+of a Moose application, then make sure you have MooseX::Types
+installed.
+
+=head2 Other
+
+Please report any other bugs to
 L<http://rt.cpan.org/Dist/Display.html?Queue=Web-ID>.
 
 =head1 SEE ALSO
