@@ -5,14 +5,15 @@ use utf8;
 
 BEGIN {
 	$Web::ID::Certificate::AUTHORITY = 'cpan:TOBYINK';
-	$Web::ID::Certificate::VERSION   = '1.924_03';
+	$Web::ID::Certificate::VERSION   = '1.920';
 }
 
 use Crypt::X509 0.50 ();  # why the hell does this export anything?!
 use DateTime 0;
+use Any::Moose 'X::Types::Moose' => [':all'];
 use Digest::SHA qw(sha1_hex);
 use MIME::Base64 0 qw(decode_base64);
-use Web::ID::Types -types;
+use Web::ID::Types qw(:all);
 use Web::ID::SAN;
 use Web::ID::SAN::Email;
 use Web::ID::SAN::URI;
@@ -21,71 +22,74 @@ use Web::ID::Util qw(:default part);
 # Partly sorts a list of Web::ID::SAN objects,
 # prioritising URIs and Email addresses.
 #
+# Note: placing this deliberately before namespace::clean.
+#
 sub _sort_san
 {
 	map  { ref($_) eq 'ARRAY' ? (@$_) : () }
 	part {
-		if ($_->isa("Web::ID::SAN::URI"))       { 0 }
-		elsif ($_->isa("Web::ID::SAN::Email"))  { 1 }
+		if ($_->isa('Web::ID::SAN::URI'))       { 0 }
+		elsif ($_->isa('Web::ID::SAN::Email'))  { 1 }
 		else                                    { 2 }
 	}
 	@_;
 }
 
-use Moose;
-use namespace::sweep -also => '_sort_san';
+use Any::Moose;
+use namespace::clean -except => 'meta';
 
 has pem => (
 	is          => read_only,
 	isa         => Str,
 	required    => true,
 	coerce      => false,
-);
+	);
 
 has _der => (
 	is          => read_only,
 	isa         => Str,
 	required    => true,
 	lazy_build  => true,
-);
+	);
 
 has _x509 => (
 	is          => read_only,
-	isa         => Type::Utils::class_type({ class => "Crypt::X509" }),
+	isa         => 'Crypt::X509',
 	lazy_build  => true,
-);
+	);
 
 has public_key => (
 	is          => read_only,
 	isa         => Rsakey,
 	lazy_build  => true,
 	handles     => [qw(modulus exponent)],
-);
+	);
 
 has subject_alt_names => (
 	is          => read_only,
 	isa         => ArrayRef,
 	lazy_build  => true,
-);
+	);
 
 has $_ => (
 	is          => read_only,
 	isa         => Datetime,
 	lazy_build  => true,
 	coerce      => true,
-) for qw( not_before not_after );
+	)
+	for qw( not_before not_after );
 
 has san_factory => (
 	is          => read_only,
 	isa         => CodeRef,
 	lazy_build  => true,
-);
+	);
 
 has fingerprint => (
 	is          => read_only,
 	isa         => Str,
 	lazy_build  => true,
-);
+	);
 
 sub _build_fingerprint
 {
@@ -100,13 +104,13 @@ sub _build__der
 
 sub _build__x509
 {
-	return "Crypt::X509"->new(cert => shift->_der);
+	return Crypt::X509->new(cert => shift->_der);
 }
 
 sub _build_public_key
 {
 	my ($self) = @_;
-	Rsakey->new($self->_x509->pubkey_components);
+	Web::ID::RSAKey->new($self->_x509->pubkey_components);
 }
 
 sub _build_subject_alt_names
@@ -142,7 +146,7 @@ my $default_san_factory = sub
 			uniformResourceIdentifier  => 'Web::ID::SAN::URI',
 			rfc822Name                 => 'Web::ID::SAN::Email',
 		}->{ $args{type} }
-		// "Web::ID::SAN";
+		// 'Web::ID::SAN';
 	$class->new(%args);
 };
 
@@ -154,7 +158,7 @@ sub _build_san_factory
 sub timely
 {
 	my ($self, $now) = @_;
-	$now //= Datetime->class->now;
+	$now //= DateTime->now;
 	
 	return if $now > $self->not_after;
 	return if $now < $self->not_before;
@@ -185,7 +189,7 @@ Web::ID::Certificate - an x509 certificate
 
 =item C<< new >>
 
-Standard Moose-style constructor. 
+Standard Moose-style constructor. (This class uses L<Any::Moose>.)
 
 =back
 
