@@ -5,14 +5,15 @@ use utf8;
 
 BEGIN {
 	$Web::ID::RSAKey::AUTHORITY = 'cpan:TOBYINK';
-	$Web::ID::RSAKey::VERSION   = '1.924_03';
+	$Web::ID::RSAKey::VERSION   = '1.920';
 }
 
-use Web::ID::Types -types;
+use Any::Moose 'X::Types::Moose' => [':all'];
+use Web::ID::Types ':all';
 use Web::ID::Util;
 
-use Moose;
-use namespace::sweep;
+use Any::Moose;
+use namespace::clean -except => 'meta';
 
 for (qw( exponent modulus ))
 {
@@ -21,7 +22,7 @@ for (qw( exponent modulus ))
 		isa         => Bigint,
 		required    => true,
 		coerce      => true,
-	);
+		);
 }
 
 sub rsa_equal
@@ -53,7 +54,7 @@ Web::ID::RSAKey - an RSA key
 
 =item C<< new >>
 
-Standard Moose-style constructor. 
+Standard Moose-style constructor. (This class uses L<Any::Moose>.)
 
 =back
 
