@@ -5,41 +5,43 @@ use utf8;
 
 BEGIN {
 	$Web::ID::SAN::AUTHORITY = 'cpan:TOBYINK';
-	$Web::ID::SAN::VERSION   = '1.924_03';
+	$Web::ID::SAN::VERSION   = '1.920';
 }
 
-use Web::ID::Types -types;
+use Any::Moose 'X::Types::Moose' => [':all'];
+use Web::ID::Types ':all';
 use RDF::Query 2.900;
 use URI 0;
 use URI::Escape 0 qw/uri_escape/;
 use Web::ID::RSAKey;
 use Web::ID::Util;
 
-use Moose;
-use namespace::sweep;
+use Any::Moose;
+use namespace::clean -except => 'meta';
 
 has $_ => (
 	is          => read_only,
 	isa         => Str,
 	required    => true,
 	coerce      => false,
-) for qw(type value);
+	)
+	for qw(type value);
 
 has model => (
 	is          => read_only,
 	isa         => Model,
 	lazy_build  => true,
-);
+	);
 
 has key_factory => (
 	is          => read_only,
 	isa         => CodeRef,
 	lazy_build  => true,
-);
+	);
 
 sub _build_model
 {
-	return Model->new;
+	return RDF::Trine::Model->new;
 }
 
 my $default_key_factory = sub
@@ -47,7 +49,7 @@ my $default_key_factory = sub
 	my (%args) = @_;
 	return unless $args{exponent};
 	return unless $args{modulus};
-	Rsakey->new(%args);
+	Web::ID::RSAKey->new(%args);
 };
 
 sub _build_key_factory
@@ -58,7 +60,7 @@ sub _build_key_factory
 sub uri_object
 {
 	my ($self) = @_;
-	return Uri->new(sprintf 'urn:x-subject-alt-name:%s:%s', map {uri_escape $_} $self->type, $self->value);
+	return URI->new(sprintf 'urn:x-subject-alt-name:%s:%s', map {uri_escape $_} $self->type, $self->value);
 }
 
 sub to_string
@@ -87,7 +89,7 @@ Web::ID::SAN - represents a single name from a certificate's subjectAltName fiel
 
 =item C<< new >>
 
-Standard Moose-style constructor. 
+Standard Moose-style constructor. (This class uses L<Any::Moose>.)
 
 =back
 
