@@ -7,7 +7,7 @@ our $WWW_Finger = 0;
 
 BEGIN {
 	$Web::ID::SAN::Email::AUTHORITY = 'cpan:TOBYINK';
-	$Web::ID::SAN::Email::VERSION   = '1.924_03';
+	$Web::ID::SAN::Email::VERSION   = '1.920';
 	
 	eval {
 		no warnings;
@@ -17,12 +17,13 @@ BEGIN {
 	}
 }
 
-use Web::ID::Types -types;
+use Any::Moose 'X::Types::Moose' => [':all'];
+use Web::ID::Types ':all';
 use Web::ID::Util;
 
-use Moose;
-use namespace::sweep;
-extends "Web::ID::SAN";
+use Any::Moose;
+use namespace::clean -except => 'meta';
+extends 'Web::ID::SAN';
 
 has '+type' => (default => 'rfc822Name');
 
@@ -31,7 +32,7 @@ has finger => (
 	isa         => Finger | Undef,
 	lazy        => true,
 	builder     => '_build_finger',
-);
+	);
 
 sub _build_finger
 {
@@ -47,8 +48,8 @@ around _build_model => sub
 	{
 		if ($finger->endpoint)
 		{
-			my $store = "RDF::Trine::Store::SPARQL"->new($finger->endpoint);
-			return Model->new($store);
+			my $store = RDF::Trine::Store::SPARQL->new($finger->endpoint);
+			return RDF::Trine::Model->new($store);
 		}
 		return $finger->graph;
 	}
@@ -68,17 +69,17 @@ around associated_keys => sub
 			$result->{modulus},
 			fallback      => $result->{hexModulus},
 			fallback_type =>'hex',
-		);
+			);
 		my $exponent = make_bigint_from_node(
 			$result->{exponent},
 			fallback      => $result->{decExponent},
 			fallback_type =>'dec',
-		);
+			);
 				
 		my $key = $self->key_factory->(
 			modulus  => $modulus,
 			exponent => $exponent,
-		);
+			);
 		push @keys, $key if $key;
 	}
 	
@@ -89,7 +90,7 @@ sub _query
 {
 	my ($self) = @_;
 	my $email = 'mailto:' . $self->value;
-	return "RDF::Query"->new( sprintf(<<'SPARQL', (($email)x4)) );
+	return RDF::Query->new( sprintf(<<'SPARQL', (($email)x4)) );
 PREFIX cert: <http://www.w3.org/ns/auth/cert#>
 PREFIX rsa: <http://www.w3.org/ns/auth/rsa#>
 PREFIX foaf: <http://xmlns.com/foaf/0.1/>
