@@ -6,24 +6,28 @@ use utf8;
 
 BEGIN {
 	$Web::ID::Util::AUTHORITY = 'cpan:TOBYINK';
-	$Web::ID::Util::VERSION   = '1.924_03';
+	$Web::ID::Util::VERSION   = '1.920';
 }
 
-use match::simple qw/match/;
 use Carp qw/confess/;
 use Math::BigInt 0 try => 'GMP';
 use RDF::Trine::NamespaceMap;
 use List::MoreUtils qw(:all !true !false);
 
-use base "Exporter::TypeTiny";
-our @EXPORT = qw(
-	make_bigint_from_node get_trine_model u uu
-	true false read_only read_write
-);
-our @EXPORT_OK = (
-	@EXPORT,
-	grep {!/^(true|false)$/} @List::MoreUtils::EXPORT_OK
-);
+our (@EXPORT, @EXPORT_OK);
+BEGIN {
+	@EXPORT    = qw(make_bigint_from_node get_trine_model u uu
+	                true false read_only read_write);
+	@EXPORT_OK = (@EXPORT, grep {!/^(true|false)$/} @List::MoreUtils::EXPORT_OK);
+}
+
+use Sub::Exporter -setup => {
+	exports => \@EXPORT_OK,
+	groups  => {
+		default  => \@EXPORT,
+		all      => \@EXPORT_OK,
+	},
+};
 
 use constant {
 	read_only  => 'ro',
@@ -66,9 +70,9 @@ sub get_trine_model
 {
 	my ($uri, $model) = @_;
 	
-	$model //= "RDF::Trine::Model"->new;
+	$model //= RDF::Trine::Model->new;
 	eval {
-		"RDF::Trine::Parser"->parse_url_into_model($uri, $model);
+		RDF::Trine::Parser->parse_url_into_model($uri, $model);
 	};
 	
 	return $model;
@@ -108,37 +112,37 @@ sub make_bigint_from_node
 	
 	if ($node->is_literal)
 	{
-		for ($node->literal_datatype)
+		given ($node->literal_datatype)
 		{
-			if (match $_, $test_hex)
+			when ($_ ~~ $test_hex)
 			{
 				( my $hex = $node->literal_value ) =~ s/[^0-9A-F]//ig;
-				return "Math::BigInt"->from_hex("0x$hex");
+				return Math::BigInt->from_hex("0x$hex");
 			}
 			
-			if (match $_, $test_unsigned)
+			when ($_ ~~ $test_unsigned)
 			{
 				( my $dec = $node->literal_value ) =~ s/[^0-9]//ig;
-				return "Math::BigInt"->new("$dec");
+				return Math::BigInt->new("$dec");
 			}
 			
-			if (match $_, $test_signed)
+			when ($_ ~~ $test_signed)
 			{
 				( my $dec = $node->literal_value ) =~ s/[^0-9-]//ig;
-				return "Math::BigInt"->new("$dec");
+				return Math::BigInt->new("$dec");
 			}
 			
-			if (match $_, $test_decimal)
+			when ($_ ~~ $test_decimal)
 			{
 				my ($dec, $frac) = split /\./, $node->literal_value, 2;
 				warn "Ignoring fractional part of xsd:decimal number."
 					if defined $frac;
 				
 				$dec =~ s/[^0-9-]//ig;
-				return "Math::BigInt"->new("$dec");
+				return Math::BigInt->new("$dec");
 			}
 			
-			if (match $_, undef)
+			when ($_ ~~ undef)
 			{
 				$opts{'fallback'} = $node;
 			}
@@ -151,7 +155,7 @@ sub make_bigint_from_node
 		if ($opts{'fallback_type'} eq 'hex')
 		{
 			(my $hex = $node->literal_value) =~ s/[^0-9A-F]//ig;
-			return "Math::BigInt"->from_hex("0x$hex");
+			return Math::BigInt->from_hex("0x$hex");
 		}
 		else # dec
 		{
@@ -160,7 +164,7 @@ sub make_bigint_from_node
 				if defined $frac;
 				
 			$dec =~ s/[^0-9]//ig;
-			return "Math::BigInt"->new("$dec");
+			return Math::BigInt->new("$dec");
 		}
 	}
 	
@@ -181,8 +185,8 @@ These are utility functions which I found useful building Web-ID.
 Many of them may also be useful creating the kind of apps that
 Web-ID is used to authenticate for.
 
-Here is a very brief summary. By B<default>, they're B<all> exported
-to your namespace. (This modulue uses L<Exporter::TypeTiny> so you get
+Here is a very brief summary. By default, they're B<all> exported
+to your namespace. (This modulue uses L<Sub::Exporter> so you get
 pretty good control over what gets exported.)
 
 =over
@@ -230,7 +234,6 @@ L<Web::ID> itself.
 
 =head1 SEE ALSO
 
-L<Exporter::TypeTiny>,
 L<Web::ID>,
 L<Acme::24>.
 
